@@ -1,6 +1,4 @@
 
-#ifndef DBDQUOTEH
-#define DBDQUOTEH
 char * null_quote(const char *string, STRLEN len, STRLEN *retlen);
 char * quote_string(const char *string, STRLEN len, STRLEN *retlen);
 char * quote_bytea(char *string, STRLEN len, STRLEN *retlen);
@@ -16,4 +14,3 @@ void dequote_bytea(char *string, STRLEN *retlen);
 void dequote_sql_binary(char *string, STRLEN *retlen);
 void dequote_bool(char *string, STRLEN *retlen);
 void null_dequote(const char *string, STRLEN *retlen);
-#endif /*DBDQUOTEH*/
